==> jsonstreamreader-1.1.1.tar.gz: lib/state/reader/token/jsontokenstate.dart <==
import 'dart:convert';

/// Represents the last know state of all JsonTokens
class JsonTokenState {
  Map<int, Map<String, dynamic>> _queue = new Map<int, Map<String, dynamic>>();
  //unclosed objects ids
  int _osi;
  List<int> _os = new List<int>();
  //unclosed arrays ids
  int _asi;
  int _fired;
  List<int> _als = List<int>();
  List<Map<String, dynamic>> _partners = List<Map<String, dynamic>>();
  List<Map<String, dynamic>> _parents = new List<Map<String, dynamic>>();
  String _path;
  int _quotes;
  JsonTokenState(
      Map<int, Map<String, dynamic>> queue,
      int osi,
      List<int> os,
      int asi,
      int fired,
      List<int> als,
      List<Map<String, dynamic>> partners,
      List<Map<String, dynamic>> parents,
      String path,
      int quotes) {
    this._queue = queue;
    this._osi = osi;
    this._os = os;
    this._asi = asi;
    this._fired = fired;
    this._als = als;
    this._partners = partners;
    this._parents = parents;
    this._path = path;
    this._quotes = quotes;
  }
  JsonTokenState.empty();
  //Convert state to string
  String toString() {
    Map<String, dynamic> details = new Map<String, dynamic>();
    details['queue'] = new Map<String, dynamic>();
    _queue.forEach((int key, Map<String, dynamic> value) {
      details['queue'][key.toString()] = value;
    });
    details['osi'] = _osi;
    details['os'] = _os;
    details['asi'] = _asi;
    details['fired'] = _fired;
    details['als'] = _als;
    details['partners'] = _partners;
    details['parents'] = _parents;
    details['path'] = _path;
    details['quotes'] = _quotes;
    return jsonEncode(details);
  }

  //Convert state to map
  Map<String, dynamic> toMap() {
    Map<String, dynamic> details = new Map<String, dynamic>();
    details['queue'] = new Map<String, dynamic>();
    _queue.forEach((int key, Map<String, dynamic> value) {
      details['queue'][key.toString()] = value;
    });
    details['osi'] = _osi;
    details['os'] = _os;
    details['asi'] = _asi;
    details['fired'] = _fired;
    details['als'] = _als;
    details['partners'] = _partners;
    details['parents'] = _parents;
    details['path'] = _path;
    details['quotes'] = _quotes;
    return details;
  }

  Map<String, dynamic> data() {
    Map<String, dynamic> details = new Map<String, dynamic>();
    details['queue'] = _queue;
    details['osi'] = _osi;
    details['os'] = _os;
    details['asi'] = _asi;
    details['fired'] = _fired;
    details['als'] = _als;
    details['partners'] = _partners;
    details['parents'] = _parents;
    details['path'] = _path;
    details['quotes'] = _quotes;
    return details;
  }

  JsonTokenState.fromString(String details) {
    dynamic decoded = jsonDecode(details);
    decoded['queue'].forEach((String key, dynamic value) {
      _queue[int.parse(key)] = value;
    });
    _osi = decoded['osi'];
    _os = List.from(decoded['os']);
    _asi = decoded['asi'];
    _fired = decoded['fired'];
    _als = List.from(decoded['als']);
    _partners = List.from(decoded['partners']);
    _parents = List.from(decoded['parents']);
    _path = decoded['path'];
    _quotes = decoded['quotes'];
  }

  JsonTokenState fromMap(Map<String, dynamic> decoded) {
    decoded['queue'].forEach((String key, dynamic value) {
      _queue[int.parse(key)] = value;
    });
    _osi = decoded['osi'];
    _os = List.from(decoded['os']);
    _asi = decoded['asi'];
    _fired = decoded['fired'];
    _als = List.from(decoded['als']);
    _partners = List.from(decoded['partners']);
    _parents = List.from(decoded['parents']);
    _path = decoded['path'];
    _quotes = decoded['quotes'];
    return this;
  }
}

==> jsonstreamreader-1.1.6.tar.gz: lib/state/reader/token/jsontokenstate.dart <==
import 'dart:convert';

/// Represents the last know state of all JsonTokens
class JsonTokenState {
  Map<int, Map<String, dynamic>> _queue = new Map<int, Map<String, dynamic>>();
  //unclosed objects ids
  //unclosed arrays ids
  List<Map<String, dynamic>> _partners = List<Map<String, dynamic>>();
  List<Map<String, dynamic>> _parents = new List<Map<String, dynamic>>();
  int _quotes;
  JsonTokenState(
      Map<int, Map<String, dynamic>> queue,
      List<Map<String, dynamic>> partners,
      List<Map<String, dynamic>> parents,
      int quotes) {
    this._queue = queue;
    this._partners = partners;
    this._parents = parents;
    this._quotes = quotes;
  }
  JsonTokenState.empty();

  ///Convert state to string
  String toString() {
    Map<String, dynamic> details = new Map<String, dynamic>();
    details['queue'] = new Map<String, dynamic>();
    _queue.forEach((int key, Map<String, dynamic> value) {
      details['queue'][key.toString()] = value;
    });
    details['partners'] = _partners;
    details['parents'] = _parents;
    details['quotes'] = _quotes;
    return jsonEncode(details);
  }

  ///Convert state to map
  Map<String, dynamic> toMap() {
    Map<String, dynamic> details = new Map<String, dynamic>();
    details['queue'] = new Map<String, dynamic>();
    _queue.forEach((int key, Map<String, dynamic> value) {
      details['queue'][key.toString()] = value;
    });
    details['partners'] = _partners;
    details['parents'] = _parents;
    details['quotes'] = _quotes;
    return details;
  }

  Map<String, dynamic> data() {
    Map<String, dynamic> details = new Map<String, dynamic>();
    details['queue'] = _queue;
    details['partners'] = _partners;
    details['parents'] = _parents;
    details['quotes'] = _quotes;
    return details;
  }

  ///Create JsonTokenState from String
  JsonTokenState.fromString(String details) {
    dynamic decoded = jsonDecode(details);
    decoded['queue'].forEach((String key, dynamic value) {
      _queue[int.parse(key)] = value;
    });
    _partners = List.from(decoded['partners']);
    _parents = List.from(decoded['parents']);
    _quotes = decoded['quotes'];
  }

  JsonTokenState fromMap(Map<String, dynamic> decoded) {
    decoded['queue'].forEach((String key, dynamic value) {
      _queue[int.parse(key)] = value;
    });
    _partners = List.from(decoded['partners']);
    _parents = List.from(decoded['parents']);
    _quotes = decoded['quotes'];
    return this;
  }
}
